================
53.0 Rear Window
================

The Avocado team is proud to present another release: Avocado version
53.0, aka, "Rear Window" now available!

Release documentation: `Avocado 53.0
<http://avocado-framework.readthedocs.io/en/53.0/>`_

The major changes introduced on this version are listed below,
roughly categorized into major topics and intended audience:

Users/Test Writers
==================

* A new loader implementation, that reuses (and resembles) the YAML
  input used for the varianter yaml_to_mux plugin.  It allows the
  definition of test suite based on a YAML file, including different
  variants for different tests.  For more information refer to
  :ref:`yaml_loader`.

* A better handling of interruption related signals, such as
  ``SIGINT`` and ``SIGTERM``.  Avocado will now try harder to not
  leave test processes that don't respond to those signals, and will
  itself behave better when it receives them.  For a complete
  description refer to `signal_handlers`.

* The output generated by tests on ``stdout`` and ``stderr`` are now
  properly prefixed with ``[stdout]`` and ``[stderr]`` in the
  ``job.log``.  The prefix is **not** applied in the case of
  ``$test_result/stdout`` and ``$test_result/stderr`` files, as one
  would expect.

* Test writers will get better protection against mistakes when trying
  to overwrite :class:`avocado.core.test.Test` "properties".  Some of
  those were previously implemented using
  :func:`avocado.utils.data_structures.LazyProperty` which did not
  prevent test writers from overwriting them.

Internal Changes
================

* Some :class:`avocado.core.test.Test` "properties" were implemented
  as lazy properties, but without the need to be so.  Those have now
  be converted to pure Python properties.

* The deprecated ``jobdata/urls`` link to ``jobdata/test_references``
  has been removed.

* The ``avocado`` command line argument parser is now invoked before
  plugins are initialized, which allows the use of ``--config`` with
  configuration file that influence plugin behavior.

For more information, please check out the complete
`Avocado changelog
<https://github.com/avocado-framework/avocado/compare/52.0...53.0>`_.

Release Meeting
===============

The Avocado release meetings are now open to the community via
Hangouts on Air.  The meetings are recorded and made available on the
`Avocado Test Framework YouTube channel
<https://www.youtube.com/channel/UC-RVZ_HFTbEztDM7wNY4NfA>`_.

For this release, you can watch the meeting on `this link
<https://www.youtube.com/watch?v=E4HpNZjBCYA>`_.

----

| Sprint theme: https://trello.com/c/SfBg9gdl/1072-sprint-theme-rear-window-1954
